@@ -6,4 +6,4 @@ from testapp.models import CommonInfoBasedModel
 class CommonInfoBasedModelTestForm(forms.ModelForm):
     class Meta:
         model = CommonInfoBasedModel
-        exclude = ()
+        fields = ('value',)
